ALTAI_NUMBER_LENGTH, ALTAI_NUMBER_HEIGHT, ALTAI_NUMBER_WIDTH = 5, 96, 96
ALTAI_PROD_LENGTH, ALTAI_PROD_HEIGHT, ALTAI_PROD_WIDTH = 4, 96, 96
ALTAI_YEAR_LENGTH, ALTAI_YEAR_HEIGHT, ALTAI_YEAR_WIDTH = 2, 64, 64
BEGICKAYA_NUMBER_LENGTH, BEGICKAYA_NUMBER_HEIGHT, BEGICKAYA_NUMBER_WIDTH = 5, 64, 64
BEGICKAYA_PROD_LENGTH, BEGICKAYA_PROD_HEIGHT, BEGICKAYA_PROD_WIDTH = 2, 64, 64
BEGICKAYA_YEAR_LENGTH, BEGICKAYA_YEAR_HEIGHT, BEGICKAYA_YEAR_WIDTH = 2, 64, 64
PROMLIT_NUMBER_LENGTH, PROMLIT_NUMBER_HEIGHT, PROMLIT_NUMBER_WIDTH = 5, 192, 192
PROMLIT_PROD_LENGTH, PROMLIT_PROD_HEIGHT, PROMLIT_PROD_WIDTH = 2, 128, 128
PROMLIT_YEAR_LENGTH, PROMLIT_YEAR_HEIGHT, PROMLIT_YEAR_WIDTH = 2, 32, 32
RUZHIMMASH_NUMBER_LENGTH, RUZHIMMASH_NUMBER_HEIGHT, RUZHIMMASH_NUMBER_WIDTH = 5, 128, 128
RUZHIMMASH_PROD_LENGTH, RUZHIMMASH_PROD_HEIGHT, RUZHIMMASH_PROD_WIDTH = 4, 96, 96
RUZHIMMASH_YEAR_LENGTH, RUZHIMMASH_YEAR_HEIGHT, RUZHIMMASH_YEAR_WIDTH = 2, 64, 64
TIHVIN_NUMBER_LENGTH, TIHVIN_NUMBER_HEIGHT, TIHVIN_NUMBER_WIDTH = 5, 128, 128
TIHVIN_PROD_LENGTH, TIHVIN_PROD_HEIGHT, TIHVIN_PROD_WIDTH = 4, 64, 64
TIHVIN_YEAR_LENGTH, TIHVIN_YEAR_HEIGHT, TIHVIN_YEAR_WIDTH = 2, 64, 64