class Danila_balka_text_detect_params:
    def __init__(self, balka_detect_version, balka_text_detect_version):
        self.balka_detect_version = balka_detect_version
        self.balka_text_detect_version = balka_text_detect_version