class Danila_balka_classify_params:
    def __init__(self, balka_classify_version, balka_classify_model):
        self.balka_classify_version = balka_classify_version
        self.balka_classify_model = balka_classify_model