class Danila_vagon_params:
    def __init__(self, danila_vagon_text_detect_params, danila_vagon_text_recognize_params):
        self.danila_vagon_text_detect_params = danila_vagon_text_detect_params
        self.danila_vagon_text_recognize_params = danila_vagon_text_recognize_params
