class Danila_rama_params:
    def __init__(self, danila_rama_classify_params, danila_rama_text_detect_params, danila_rama_text_recognize_params):
        self.danila_rama_classify_params = danila_rama_classify_params
        self.danila_rama_text_detect_params = danila_rama_text_detect_params
        self.danila_rama_text_recognize_params = danila_rama_text_recognize_params